# MeetMy.bot Clone

**Maintainers:** [Your Name]
**Project Page:** https://www.drupal.org/project/meetmy_bot_clone
**Issue Queue:** https://www.drupal.org/project/issues/meetmy_bot_clone

## INTRODUCTION

The MeetMy.bot Clone module provides seamless integration of MeetMy.bot Clone by Eternity.ac for business into Drupal websites. This module enables site administrators to embed interactive AI bot interfaces with customizable display options and optional preview video functionality.

MeetMy.bot Clone is a conversational AI platform designed for business applications, offering sophisticated chatbot capabilities for customer engagement, support, and lead generation.

## FEATURES

* **Configurable Bot Interface**: Complete control over bot URL, dimensions, and display preferences
* **Preview Video Integration**: Optional preview video that plays before bot interface activation
* **Flexible Block System**: Create multiple bot instances with individual configuration overrides
* **Responsive Design**: Mobile-first approach with adaptive layouts for all screen sizes
* **Accessibility Compliant**: Full WCAG 2.1 AA compliance with keyboard navigation and screen reader support
* **Modal Interface**: Clean overlay presentation with proper focus management and escape handling
* **Administrative Interface**: Intuitive configuration forms with validation and help text
* **Performance Optimized**: Lazy loading, efficient asset management, and minimal DOM impact

## REQUIREMENTS

* Drupal 10.0 or higher, or Drupal 11.0 or higher
* PHP 8.1 or higher (as required by Drupal core)
* Modern web browser with JavaScript enabled
* Valid MeetMy.bot Clone service URL from Eternity.ac
* SSL certificate recommended for secure iframe embedding

## INSTALLATION

### Via Composer (Recommended)

```bash
composer require drupal/meetmy_bot_clone
drush en meetmy_bot_clone
```

### Manual Installation

1. Download the latest release from the project page
2. Extract to your `modules/contrib` directory
3. Enable the module:
   ```bash
   drush en meetmy_bot_clone
   ```
4. Clear caches:
   ```bash
   drush cr
   ```

## CONFIGURATION

### Global Module Configuration

1. Navigate to **Administration » Configuration » Web Services » MeetMy.bot Clone**
   (`/admin/config/services/meetmy-bot-clone`)

2. Configure the following required settings:
   - **Title**: Display title for the bot interface (e.g., "Customer Support Bot")
   - **Bot URL**: Complete HTTPS URL to your MeetMy.bot Clone instance
   - **Window Width**: Width in pixels (200-2000, default: 400)
   - **Window Height**: Height in pixels (300-1200, default: 600)

3. Optional settings:
   - **Preview Video URL**: URL to MP4 video that plays before bot activation

4. Save configuration

### Block Placement and Configuration

1. Navigate to **Structure » Block Layout** (`/admin/structure/block`)
2. Click "Place block" in your desired region
3. Find and select "MeetMy.bot Clone" block
4. Configure block-specific settings:
   - **Override global title**: Use custom title for this block instance
   - **Override global dimensions**: Use custom width/height for this block
   - **Show preview video**: Enable/disable preview video for this block
5. Configure standard block settings (visibility, pages, roles, etc.)
6. Save block configuration

## USAGE

### Basic Implementation

After configuration, the bot interface will be available wherever you place the blocks. Users can:

1. **With Preview Video**: Click the video preview to play, then automatically launch the bot
2. **Without Preview**: Click the launch button to immediately open the bot interface
3. **Interact**: Use the embedded bot interface for conversations
4. **Close**: Click the X button or press Escape to close the modal

### Multiple Bot Instances

You can create multiple blocks with different configurations:
- Different titles for different purposes (Support, Sales, etc.)
- Various sizes for different page layouts
- Enable/disable preview videos per instance

### Theming and Customization

Override the default template by copying `meetmy-bot-clone-block.html.twig` to your theme and customizing as needed.

Available CSS classes for styling:
- `.meetmy-bot-clone-wrapper`: Main container
- `.meetmy-bot-preview`: Video preview container
- `.meetmy-bot-interface`: Modal interface container
- `.meetmy-bot-launch-button`: Launch button (when no preview)

## PERMISSIONS

* **Administer MeetMy.bot Clone**: Access to configuration forms and settings

Assign this permission to roles that should be able to configure the module (typically Administrator and Site Manager roles).

## API DOCUMENTATION

### Services

**meetmy_bot_clone.config_manager**
- `getTitle()`: Returns configured bot title
- `getBotUrl()`: Returns bot service URL
- `getWindowWidth()`: Returns interface width
- `getWindowHeight()`: Returns interface height
- `getPreviewVideoUrl()`: Returns preview video URL
- `isConfigured()`: Checks if module is properly configured

### Hooks

The module implements standard Drupal hooks:
- `hook_help()`: Provides contextual help documentation
- `hook_theme()`: Registers template files and variables
- `hook_requirements()`: Runtime status and configuration checks

### Events and Behaviors

JavaScript behavior `Drupal.behaviors.meetmyBotClone` handles:
- Modal interface management
- Video preview playback
- Keyboard accessibility
- Focus management
- Responsive behavior

## TROUBLESHOOTING

### Common Issues

**Bot Interface Not Loading**
- Verify bot URL is accessible and returns valid content
- Check browser developer console for JavaScript errors
- Ensure iframe embedding is allowed by the bot service
- Confirm SSL certificate is valid if using HTTPS

**Preview Video Not Playing**
- Verify video URL returns valid MP4 content
- Check browser autoplay policies (most browsers block autoplay)
- Test video URL directly in browser
- Consider providing user-initiated playback fallback

**Block Not Displaying**
- Confirm module configuration is complete at `/admin/config/services/meetmy-bot-clone`
- Verify block placement and visibility conditions
- Check user permissions for viewing blocks
- Clear all Drupal caches (`drush cr`)

**Mobile Display Issues**
- Test responsive breakpoints in browser dev tools
- Verify CSS is loading correctly
- Check for theme CSS conflicts
- Test on actual mobile devices

### Performance Optimization

- Use CDN for preview videos when possible
- Implement lazy loading for multiple bot instances
- Consider caching bot responses if supported by service
- Monitor iframe loading performance

### Security Considerations

- Always use HTTPS URLs for bot services
- Implement Content Security Policy headers for iframe sources
- Validate all user inputs in configuration forms
- Host preview videos on trusted domains
- Regular security updates for the module

## ACCESSIBILITY

This module follows WCAG 2.1 AA guidelines:

- **Keyboard Navigation**: Full keyboard support with logical tab order
- **Screen Reader Support**: Proper ARIA labels and semantic markup
- **Focus Management**: Focus trapping in modal, return focus on close
- **Color Contrast**: Meets minimum contrast requirements
- **Mobile Accessibility**: Touch-friendly targets and gestures

### Testing Accessibility

- Test with keyboard-only navigation
- Verify with screen readers (NVDA, JAWS, VoiceOver)
- Check color contrast ratios
- Test with browser zoom up to 200%

## MAINTAINERS

Current maintainers:
* [Your Name] - [Your Drupal.org username]

This project is looking for additional maintainers. If you're interested in helping maintain this module, please contact the current maintainers.

## SUPPORTING ORGANIZATIONS

* **Eternity.ac** - Provides the MeetMy.bot Clone service platform

## CHANGELOG

**1.0.0** (Initial Release)
- Basic bot interface integration
- Configuration form with validation
- Block plugin with override options
- Preview video support
- Responsive design implementation
- Accessibility features
- Documentation and help system

## RELATED MODULES

* **Block** (Core) - Required for block functionality
* **System** (Core) - Required for configuration management

## LICENSE

This project is licensed under the GNU General Public License v2.0 or later.
See the LICENSE.txt file for details.

## CREDITS

* **MeetMy.bot Clone Platform**: Eternity.ac for business
* **Drupal Integration**: Custom development for Drupal community
* **Icons**: Custom SVG icons for interface elements