(function ($, Drupal, drupalSettings, once) {
  'use strict';

  Drupal.behaviors.meetmyBotClone = {
    attach: function (context, settings) {
      const elements = once('meetmy-bot-clone', '.meetmy-bot-clone-wrapper', context);
      elements.forEach(function (element) {
        var $wrapper = $(element);
        var displayMode = $wrapper.data('display-mode') || 'modal';
        var modalFullscreen = $wrapper.data('modal-fullscreen') === '1';
        var $preview = $wrapper.find('.meetmy-bot-preview');

        // Правильное определение интерфейса
        var $interface, $launchButton;
        if (displayMode === 'inline') {
          $interface = $wrapper.find('.meetmy-bot-interface-inline');
          $launchButton = $wrapper.find('.meetmy-bot-launch-inline');
        } else {
          $interface = $wrapper.find('.meetmy-bot-interface');
          $launchButton = $wrapper.find('.meetmy-bot-launch-button');
        }

        var $closeButton = $wrapper.find('.meetmy-bot-close');
        var $video = $wrapper.find('.meetmy-bot-preview-video');

        var overlay = null;

        function createOverlay() {
          if (displayMode === 'modal' && !overlay) {
            overlay = $('<div class="meetmy-bot-overlay"></div>');
            $('body').append(overlay);

            overlay.on('click', function() {
              closeBotInterface();
            });
          }
          return overlay;
        }

        function showBotInterface() {
          if (displayMode === 'modal') {
            // Modal mode - ALWAYS FULLSCREEN
            var $overlay = createOverlay();
            if ($overlay) {
              $overlay.show();
            }
            $interface.show().addClass('meetmy-bot-show');

            // Disable body scroll
            $('body').css('overflow', 'hidden');

            // Focus management for accessibility
            $interface.attr('tabindex', '-1').focus();

            // Trap focus within the modal
            trapFocus($interface[0]);
          } else {
            // Inline mode - показываем встроенный интерфейс
            $interface.show().addClass('meetmy-bot-show');

            // Прокручиваем к интерфейсу для лучшего UX
            $interface[0].scrollIntoView({ behavior: 'smooth', block: 'center' });
          }
        }

        function closeBotInterface() {
          $interface.hide().removeClass('meetmy-bot-show');
          if (overlay) {
            overlay.hide();
          }

          // Re-enable body scroll
          $('body').css('overflow', '');

          // Return focus to the trigger element
          var $trigger = $preview.length ? $preview : $launchButton;
          if ($trigger.length) {
            $trigger.focus();
          }
        }

        function launchFromVideo() {
          // Скрываем видео и показываем интерфейс
          $preview.hide();
          showBotInterface();
        }

        function trapFocus(element) {
          if (displayMode !== 'modal' || !element) return;

          var focusableElements = element.querySelectorAll(
            'button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])'
          );
          var firstFocusableElement = focusableElements[0];
          var lastFocusableElement = focusableElements[focusableElements.length - 1];

          element.addEventListener('keydown', function(e) {
            if (e.key === 'Tab') {
              if (e.shiftKey) {
                if (document.activeElement === firstFocusableElement) {
                  lastFocusableElement.focus();
                  e.preventDefault();
                }
              } else {
                if (document.activeElement === lastFocusableElement) {
                  firstFocusableElement.focus();
                  e.preventDefault();
                }
              }
            } else if (e.key === 'Escape') {
              closeBotInterface();
            }
          });
        }

        // Event handlers - КЛИК НА ВИДЕО ВМЕСТО КНОПКИ
        $preview.on('click', function(e) {
          e.preventDefault();
          launchFromVideo();
        });

        // Keyboard support для видео
        $preview.on('keydown', function(e) {
          if (e.key === 'Enter' || e.key === ' ') {
            e.preventDefault();
            launchFromVideo();
          }
        });

        // Обычная кнопка запуска (если нет видео)
        $launchButton.on('click', function(e) {
          e.preventDefault();
          showBotInterface();
        });

        $launchButton.on('keydown', function(e) {
          if (e.key === 'Enter' || e.key === ' ') {
            e.preventDefault();
            showBotInterface();
          }
        });

        // Кнопка закрытия
        $closeButton.on('click', function(e) {
          e.preventDefault();
          closeBotInterface();
        });

        // Initialize video with AUTOPLAY support
        if ($video.length) {
          $video.on('loadedmetadata', function() {
            // Video metadata loaded
          });

          $video.on('play', function() {
            // Video started playing automatically
          });

          $video.on('error', function() {
            // Hide preview if video fails to load and show launch button
            $preview.hide();
            if ($launchButton.length) {
              $launchButton.show();
            }
          });

          $video.on('pause', function() {
            var videoElement = this;
            setTimeout(function() {
              videoElement.play().catch(function(error) {
                // Video autoplay blocked by browser policy
              });
            }, 100);
          });

          // Force autoplay attempt after a short delay
          setTimeout(function() {
            if ($video[0] && $video[0].paused) {
              $video[0].play().catch(function(error) {
                // Initial autoplay attempt blocked
              });
            }
          }, 500);
        }
      });
    },

    detach: function (context, settings, trigger) {
      if (trigger === 'unload') {
        $('.meetmy-bot-overlay').remove();
        $('body').css('overflow', '');
      }
    }
  };

})(jQuery, Drupal, drupalSettings, once);